/*
** Module   : WebAuthorization.java
** Abstract : Configure the authorization for a web service request.
**
** Copyright (c) 2021, Golden Code Development Corporation.
**
** -#- -I- --Date-- ---------------------------------------Description----------------------------------------
** 001 CA  20210827 Created initial version.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import org.apache.http.client.methods.*;

/**
 * Configuration of the request for a Web Authorization.
 */
public interface WebAuthorization
{
   /**
    * Configure the request with the authorization.
    * 
    * @param    request
    *           The HTTP request.
    */
   public void setAuthorization(RequestBuilder request);
   
   /**
    * Set an authorization parameter.  This may be a HTTP header or anything else required to build the
    * authorization.
    * 
    * @param    name
    *           The parameter name.
    * @param    value
    *           The parameter value.
    */
   public void setParameter(String name, String value);
}
